//
//  View.m
//  Segmented
//
//  Created by Mark Meretzky on 11/6/13.
//  Copyright (c) 2013 Mark Meretzky. All rights reserved.
//

#import "View.h"
#import "SegmentedAppDelegate.h"	//so View.m can mention valueChanged:

@implementation View
@synthesize control;

- (id) initWithFrame: (CGRect) frame
{
	self = [super initWithFrame: frame];
	if (self) {
		// Initialization code
		self.backgroundColor = [UIColor whiteColor];

		//Create the segmented control.

		NSArray *items = [NSArray arrayWithObjects:
			@"Record",
			@"Stop",
			@"Play",
			nil
		];

		control = [[UISegmentedControl alloc] initWithItems: items];
		control.momentary = YES;

		//Can't play until we have recorded something.
		[control setEnabled: NO forSegmentAtIndex: 2];

		//Center the control in the SegmentedView.
		CGRect b = self.bounds;

		control.center = CGPointMake(
			b.origin.x + b.size.width / 2,
			b.origin.y + b.size.height / 2
		);

		[control addTarget: [UIApplication sharedApplication].delegate
			action: @selector(valueChanged:)
			forControlEvents: UIControlEventValueChanged
		];

		[self addSubview: control];

		//Create the red recording light, but don't turn it on yet.
		//Center it above the record button of the segmented control.
		CGFloat side = 10;
		CGFloat margin = 10;
		CGRect f = CGRectMake(
			(self.bounds.size.width - side) / 2 - control.bounds.size.width / 3,
			self.bounds.size.height / 2 - control.bounds.size.height / 2 - side - margin,
			side,
			side
		);
		recordingLight = [[UIView alloc] initWithFrame: f];
		recordingLight.backgroundColor = [UIColor redColor];
		recordingLight.hidden = YES;
		[self addSubview: recordingLight];
	}
    return self;
}

- (void) showRecordingLight: (BOOL) flag {
	recordingLight.hidden = !flag;
}

/*
// Only override drawRect: if you perform custom drawing.
// An empty implementation adversely affects performance during animation.
- (void) drawRect: (CGRect) rect
{
	// Drawing code
}
*/

@end
